import React from 'react'
import { Box, Typography, Grid, Paper, Avatar } from '@mui/material'
import { useParams } from 'react-router-dom'
import { format } from 'date-fns'

const generateRandomRetailerDetails = (id) => ({
  id,
  tradeName: `Trade ${id}`,
  name: `Retailer ${id}`,
  address: '123 Main St',
  townCity: 'Townsville',
  district: 'District A',
  state: 'State B',
  pincode: '123456',
  mobileNumber: '123-456-7890',
  mappedDistributor: `Distributor ${id}`,
  documents: {
    panNumber: 'ABCDE1234F',
    panCard:
      'https://www.shutterstock.com/shutterstock/photos/2329691987/display_1500/stock-vector-blank-pan-card-vector-image-income-tax-card-personal-account-number-image-translation-income-2329691987.jpg',
    aadharNumber: '1234-5678-9101',
    aadharCard: 'https://via.placeholder.com/100',
    gstNumber: '22AAAAA0000A1Z5',
    gstRegistration: 'https://via.placeholder.com/100',
    pesticideLicense: 'https://via.placeholder.com/100',
    fertilizerLicense: 'https://via.placeholder.com/100',
    entranceBoardSelfie: 'https://via.placeholder.com/100',
  },
  salesCoordinator: {
    designation: 'Sales Coordinator',
    name: `Coordinator ${id}`,
    employeeId: `EMP${id}`,
    uploadedOn: new Date(),
    resubmittedOn: new Date(),
  },
  notes: ['Note 1', 'Note 2', 'Note 3'],
})

const KycDetails = () => {
  const { id } = useParams()
  console.log(id)
  const retailerDetails = generateRandomRetailerDetails(id)

  return (
    <Box sx={{ p: 3 }}>
      <Typography variant="h4" gutterBottom>
        Retailer Details
      </Typography>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h5" gutterBottom>
          Retailer Details
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>Trade Name:</strong> {retailerDetails.tradeName}
            </Typography>
            <Typography>
              <strong>Name:</strong> {retailerDetails.name}
            </Typography>
            <Typography>
              <strong>Address:</strong> {retailerDetails.address}
            </Typography>
            <Typography>
              <strong>Town/City:</strong> {retailerDetails.townCity}
            </Typography>
          </Grid>
          <Grid item xs={6}>
            <Typography>
              <strong>District:</strong> {retailerDetails.district}
            </Typography>
            <Typography>
              <strong>State:</strong> {retailerDetails.state}
            </Typography>
            <Typography>
              <strong>Pincode:</strong> {retailerDetails.pincode}
            </Typography>
            <Typography>
              <strong>Mobile Number:</strong> {retailerDetails.mobileNumber}
            </Typography>
            <Typography>
              <strong>Mapped Principal Distributor:</strong> {retailerDetails.mappedDistributor}
            </Typography>
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Documents
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>PAN Number:</strong> {retailerDetails.documents.panNumber}
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.documents.panCard}
              sx={{ width: 100, height: 100, mb: 2 }}
            />
            <Typography>
              <strong>Aadhar Number:</strong> {retailerDetails.documents.aadharNumber}
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.documents.aadharCard}
              sx={{ width: 100, height: 100, mb: 2 }}
            />
            <Typography>
              <strong>GST Number:</strong> {retailerDetails.documents.gstNumber}
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.documents.gstRegistration}
              sx={{ width: 100, height: 100, mb: 2 }}
            />
          </Grid>
          <Grid item xs={6}>
            <Typography>
              <strong>Pesticide License:</strong>
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.documents.pesticideLicense}
              sx={{ width: 100, height: 100, mb: 2 }}
            />
            <Typography>
              <strong>Fertilizer License (optional):</strong>
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.documents.fertilizerLicense}
              sx={{ width: 100, height: 100, mb: 2 }}
            />
            <Typography>
              <strong>Selfie of Entrance Board:</strong>
            </Typography>
            <Avatar
              variant="square"
              src={retailerDetails.documents.entranceBoardSelfie}
              sx={{ width: 100, height: 100, mb: 2 }}
            />
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Block 3: Sales Coordinators/Territory Manager Details
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <Typography>
              <strong>Designation:</strong> {retailerDetails.salesCoordinator.designation}
            </Typography>
            <Typography>
              <strong>Name:</strong> {retailerDetails.salesCoordinator.name}
            </Typography>
            <Typography>
              <strong>Employee ID:</strong> {retailerDetails.salesCoordinator.employeeId}
            </Typography>
          </Grid>
          <Grid item xs={6}>
            <Typography>
              <strong>Uploaded on:</strong>{' '}
              {format(retailerDetails.salesCoordinator.uploadedOn, 'yyyy-MM-dd HH:mm:ss')}
            </Typography>
            <Typography>
              <strong>Resubmitted on:</strong>{' '}
              {format(retailerDetails.salesCoordinator.resubmittedOn, 'yyyy-MM-dd HH:mm:ss')}
            </Typography>
          </Grid>
        </Grid>
      </Paper>

      <Paper sx={{ p: 2, mb: 3 }}>
        <Typography variant="h6" gutterBottom>
          Block 4: Notes
        </Typography>
        {retailerDetails.notes.map((note, index) => (
          <Typography key={index}>{note}</Typography>
        ))}
      </Paper>
    </Box>
  )
}

export default KycDetails
